/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:45+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Map"
: "แผนที่"

, "Preferred Address"
: ""

, "Personal Information"
: "ข้อมุลส่วนบุคคล"

, "Salutation"
: "คำขึ้นต้น"

, "Title"
: "คำนำหน้าชื่อ"

, "Short Name"
: ""

, "First Name"
: "ชื่อตัว"

, "Middle Name"
: "ชื่อกลาง"

, "Last Name"
: "นามสกุล"

, "Company"
: "บริษัท"

, "Unit"
: "หน่วย/ แผนก"

, "Display Name"
: "ชื่อที่ใช้"

, "Industry, Industries"
: [
  ""

]
, "Job Title"
: "ตำแหน่งงาน"

, "Birthday (private)"
: ""

, "Contact Information"
: "ข้อมูลที่ใช้ในการติดต่อ"

, "Phone"
: "โทรศัพท์"

, "Mobile"
: "โทรศัพท์เคลื่อนที่"

, "Fax"
: "โทรสาร"

, "Phone (private)"
: "โทรศัพท์ (ส่วนตัว)"

, "Mobile (private)"
: "โทรศัพท์เคลื่อนที่ (ส่วนตัว)"

, "Fax (private)"
: "โทรสาร (ส่วนตัว)"

, "E-Mail"
: "อีเมล"

, "E-Mail (private)"
: " อีเมล (ส่วนตัว)"

, "Web"
: "เวบไซด์"

, "Company Address"
: "ที่อยู่ของบริษัท"

, "Street"
: "ถนน"

, "Street 2"
: "ถนน 2"

, "Region"
: "เขต"

, "Postal Code"
: "รหัสไปรษณีย์"

, "City"
: "เมือง"

, "Country"
: "ประเทศ"

, "Private Address"
: "ที่อยู่ส่วนบุคคล"

, "Description"
: "การอธิบาย"

, "Enter description"
: "ใส่ คำอธิบาย"

, "Groups"
: ""

, "Parse address"
: "วิเคราะห์ ที่อยู่"

, "Print contact"
: ""

, "Paste address"
: "ใส่ ที่อยู่"

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: "จบโหมดสัญลักษณ์"

, "Customfields"
: ""

, "Related to"
: ""

, "Mailing List"
: ""

, "This group is a mailing list"
: ""

, "Keep copy of group mails"
: ""

, "Forward external mails"
: ""

, "Only forward member mails"
: ""

, "Only forward to system email accounts"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Contact, Contacts"
: [
  "การติดต่อ"

]
, "Members"
: ""

, "Search for members ..."
: ""

, "List Roles"
: ""

, "Remove Member"
: ""

, "CardDAV URL"
: "CalDAV URL"

, "New Contact"
: "การติดต่อใหม่"

, "Addressbook, Addressbooks"
: [
  "สมุดรายชื่อ"

]
, "ID"
: ""

, "Name"
: "ชื่อ"

, "Structure, Structures"
: [
  ""

]
, "Resources"
: ""

, "Private"
: "ส่วนตัว"

, "The grant to access contacts private information"
: ""

, "Contact Personal Grant, Contact Personal Grants"
: [
  ""

]
, "List Personal Grant, List Personal Grants"
: [
  ""

]
, "List Information"
: ""

, "List type"
: ""

, "System accounts only"
: ""

, "{0} must be given"
: ""

, "List Functions"
: ""

, "Suffix"
: "คำลงท้ายชื่อ"

, "Birthday"
: "วันเกิด"

, "Job Role"
: "หน้าที่งาน"

, "Room"
: "ห้อง"

, "Street (Company Address)"
: "ถนน (ที่อยู่ของบริษัท)"

, "Street 2 (Company Address)"
: "ถนน 2 (ที่อยู่ของบริษัท)"

, "City (Company Address)"
: "จังหวัด  (ที่อยู่ของบริษัท)"

, "Region (Company Address)"
: "เขต  (ที่อยู่ของบริษัท)"

, "Postal Code (Company Address)"
: "รหัสไปรษณีย์  (ที่อยู่ของบริษัท)"

, "Country (Company Address)"
: "ประเทศ  (ที่อยู่ของบริษัท)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "ถนน (ที่อยู่ส่วนบุคคล)"

, "Street 2 (Private Address)"
: "ถนน 2 (ที่อยู่ส่วนบุคคล)"

, "City (Private Address)"
: "จังหวัด  (ที่อยู่ส่วนบุคคล)"

, "Region (Private Address)"
: "เขต  (ที่อยู่ส่วนบุคคล)"

, "Postal Code (Private Address)"
: "รหัสไปรษณีย์  (ที่อยู่ส่วนบุคคล)"

, "Country (Private Address)"
: "ประเทศ  (ที่อยู่ส่วนบุคคล)"

, "Company Communication"
: "การติดต่อสื่อสารของบริษัท"

, "Private Communication"
: "การติดต่อสื่อสารส่วนบุคคล"

, "Web (private)"
: "เวบไซด์  (ส่วนตัว)"

, "Contacts"
: "การติดต่อ"

, "Addressbooks"
: "สมุดที่อยู่"

, "User Account"
: "บัญชีผู้ใช้"

, "Quick Search"
: "ค้นหาอย่างรวดเร็ว"

, "Type"
: "ประเภท"

, "Last Modified Time"
: "เวลาที่ปรับปรุงครั้งล่าสุด"

, "Last Modified By"
: "ปรับปรุงครั้งล่าสุด โดย"

, "Creation Time"
: "เวลาที่สร้างขึ้น"

, "Created By"
: "สร้าง โดย"

, "List, Lists"
: [
  "รายชื่อ"

]
, "Lists"
: "รายชื่อ"

, "Email Address, Email Addresses"
: [
  ""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""

]
, "GENDER_List Function"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "Business"
: ""

, "Import contacts"
: "นำเข้า การติดต่อ"

, "Contact of a user account"
: "การติดต่อของ บัญชี ผู้ใช้"

, "No name"
: ""

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "ป้ายกำกับ"

, "Full Name"
: "ชื่อเต็ม"

, "Postalcode"
: "รหัสไปรษณีย์"

, "Street (private)"
: "ถนน (ส่วนตัว)"

, "City (private)"
: "จังหวัด (ส่วนตัว)"

, "Region (private)"
: "เขต (ส่วนตัว)"

, "Postalcode (private)"
: "รหัสไปรษณีย์ (ส่วนตัว)"

, "Country (private)"
: "ประเทศ (ส่วนตัว)"

, "Email"
: "อีเมล"

, "Car phone"
: "โทรศัพท์ในรถ"

, "Pager"
: "เพจเจอร์"

, "Email (private)"
: " อีเมล (ส่วนตัว)"

, "URL (private)"
: "รหัสสืบค้นข้อมูลทางอินเตอร์เนต (ส่วนตัว)"

, "Note"
: "บันทึก"

, "Timezone"
: "เส้นแบ่งเวลา"

, "Geo"
: "ภูมิศาสตร์"

, "Select list"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "Company address"
: "ที่อยู่ของบริษัท"

, "Private address"
: "ที่อยู่ส่วนบุคคล"

, "Member E-Mails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "All contacts"
: "การติดต่อทั้งหมด"

, "Default Addressbook"
: "สมุดรายชื่อหลัก"

, "The default addressbook for new contacts"
: "สมุดรายชื่อหลักสำหรับการติดต่อใหม่"

, "Default Favorite"
: "ค่าที่ชอบหลัก"

, "The default favorite which is loaded on addressbook startup"
: "ค่าที่ชอบหลักที่จะโหลดทันทีเมื่อเริ่มเปิดสมุดที่อยู่"

, "Contacts ODS export configuration"
: "การกำหนดค่าส่งออกการติดต่อแบบ ODS"

, "Use this configuration for the contact ODS export."
: "ใช้ค่าติดตั้งนี้สำหรับการส่งออกการติดต่อแบบ ODS"

, "Contacts XLS export configuration"
: "การกำหนดค่าการส่งออกการติดต่อแบบ XLS"

, "Use this configuration for the contact XLS export."
: "ใช้กำหนดค่านี้สำหรับการส่งออกการติดต่อแบบ XLS"

, "default"
: "ค่าหลัก"

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Mailinglists"
: ""

, "Make group and lists to mailinglists"
: ""

, "Addressbook Short Names"
: ""

, "Add Short Name field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact (id) representing this installation"
: ""

, "Contact duplicate check fields"
: "การติดต่อซ้ำซ้อน ตรวจสอบที่กล่อง"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "กล่องเหล่านี้จะถูกทำเครื่องหมาย เมื่อมีการสร้างการติดต่อใหม่ขึ้น หากมีการตรวจสอบว่ามีข้อมูลที่ซ้ำซ้อนกันอยู่ ข้อยกเว้นที่ซ้ำซ้อนจะได้รับการเพิกเฉย"

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "คำขึ้นต้นที่ใช้ในการติดต่อที่มีอยู่"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "คำขึ้นต้นการติดต่อที่น่าจะเป็นไปได้ กรุณาระลึกไว้ว่าค่าเพิ่มเติมเหล่านี้อาจมีผลกระทบต่อระบบของสมุดที่อยู่เวลาส่งออกหรือการที่มีการซิงค์ข้อมูล"

, "Mr"
: "นาย"

, "Ms"
: "นาง"

, "Parsing rules for addresses"
: "กฎการตรวจสอบที่อยู่ต่าง ๆ"

, "Path to a XML file with address parsing rules."
: ""

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Site Filter"
: ""

, "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
: ""

, "Sync Backends"
: ""

, "Default telephone country code"
: ""

, "%s's personal addressbook"
: "จำนวน %s ของสมุดรายชื่อส่วนบุคคล"

, "Business Contact Data"
: "ข้อมูลการติดต่อทางธุรกิจ"

, "Organisation / Unit"
: "องค์กร / หน่วย"

, "Business Address"
: "ที่อยู่ธุรกิจ"

, "Telephone Work"
: "โทรศัพท์ ที่ทำงาน"

, "Telephone Cellphone"
: "โทรศัพท์ เคลื่อนที่"

, "Telephone Car"
: "โทรศัพท์ ในรถ"

, "Telephone Fax"
: "โทรศัพท์ โทรสาร"

, "Telephone Page"
: "โทรศัพท์ หน้า"

, "URL"
: "ที่อยู่ของไฟล์หรือเวบไซด์บนอินเตอร์เนต"

, "Role"
: "หน้าที่"

, "Assistant"
: "ผู้ช่วย"

, "Assistant Telephone"
: "โทรศัพท์ของผู้ช่วย"

, "Private Contact Data"
: "ข้อมูลการติดต่อส่วนบุคคล"

, "Email Home"
: "อีเมล ส่วนตัว"

, "Telephone Home"
: "โทรศัพท์ ที่บ้าน"

, "Telephone Cellphone Private"
: "โทรศัพท์ เคลื่อนที่ ส่วนบุคคล"

, "Telephone Fax Home"
: "โทรศัพท์ โทรสารที่บ้าน"

, "URL Home"
: " URL บ้าน"

, "Other Data"
: "ข้อมูลอื่น"

, "OpenDocument all data"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "Word letter"
: ""

, "PDF details"
: ""

, "Excel all data"
: ""

, "VCard Report"
: ""

, "Export multiple addressbooks to vcf files"
: ""

, "Relations"
: ""

, "CSV all data"
: ""

, "VCard/VCF"
: ""

, "Export contact data into vcf file"
: ""

, "Addressbooks to export"
: ""

, "Export target"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "นำเข้ารายชื่อติดต่อ CSV จากสมุดรายชื่อของโปรแกรม Outlook"

, "Contact CSV import from mac address book"
: "นำเข้ารายชื่อติดต่อ CSV จากสมุดรายชื่อของแมค"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "CSV Outlook 2007 ภาษาเยอรมัน"

, "Import CSV formated contacts from Outlook 2010 German address book"
: ""

, "CSV Outlook 2010 German"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "นำเข้ารายชื่อติดต่อ VCARD"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "นำเข้ารายชื่อ  (###วันปัจจุบัน###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "รายชื่อติดต่อถูกนำเข้าเมื่อ ###วันปัจจุบัน### ณ ###เวลาปัจจุบัน### โดย ###ชื่อเต็มของผู้ใช้###"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "รายชื่อติดต่อนำเข้ามาจากสมุดรายชื่อของกูเกิล"

, "GENDER_List"
: ""

, "Name/Email"
: ""

, "GENDER_Contact"
: ""

, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Longitude"
: ""

, "Latitude"
: ""

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Free/Busy URI"
: ""

, "Paths"
: ""

, "syncBackendIds"
: ""

, "Label"
: ""

, "It is not allowed to add non-account contacts to this list"
: ""

, "E-Mail address is already given. Please choose another one."
: ""

, "It is not allowed to delete a contact linked to an user account!"
: ""

, "This Short Name already exists. How about {0}?"
: ""

, "Internal Contacts"
: "การติดต่อภายใน"

, "All contacts I have read grants for"
: "การติดต่อทั้งหมดที่ฉันได้อ่านแล้วอนุญาตสำหรับ"

, "My company"
: "บริษัทของฉัน"

, "All coworkers in my company"
: "ผู้ร่วมงานทั้งหมดในบริษัทของฉัน"

, "My contacts"
: "ข้อมูลการติดต่อของฉัน"

, "All contacts in my Addressbooks"
: "ข้อมูลการติดต่อทั้งหมดในสมุดที่อยู่ของฉัน"

, "Last modified by me"
: "ปรับปรุงครั้งล่าสุด โดยฉัน"

, "All contacts that I have last modified"
: "การติดต่อทั้งหมดที่ฉันได้ปรับปรุงครั้งล่าสุด"

, "All Contacts"
: "การติดต่อทั้งหมด"

, "This contact has been automatically added by the system as an event attender"
: ""

, "manage shared addressbooks"
: "จัดการ สมุดรายชื่อที่ใช้ในการติดต่อร่วมกัน"

, "Create new shared addressbook folders"
: "สร้าง แฟ้มใหม่สำหรับสมุดรายชื่อที่ใช้ในการติดต่อร่วมกัน"

, "manage shared addressbook favorites"
: "จัดการ สมุดรายชื่อร่วมที่ใช้บ่อย"

, "Create or update shared addressbook favorites"
: "สร้าง หรือ ปรับปรุง สมุดรายชื่อร่วมที่ใช้บ่อย"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Manage list email options"
: ""

, "Manage list email options like mailing lists"
: ""

, "Account"
: ""

, "Exporttime"
: ""

, "28"
: ""

, "20"
: ""

, "00877546"
: ""

, "en-GB"
: ""

, "00813B4E"
: ""

, "Gruppenrollen"
: ""

, "00DA3FCD"
: ""

, "00997199"
: ""

, "0009326B"
: ""

, "008C27A5"
: ""

, "00C96397"
: ""

, "00046462"
: ""

, "Relation, Relations"
: [
  ""


]
, "Industry"
: ""

, "Contact"
: "การติดต่อ"

, "Addressbook"
: "สมุดรายชื่อ"

, "Structure"
: ""

, "Contact Personal Grant"
: ""

, "List Personal Grant"
: ""

, "List"
: "รายชื่อ"

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
